@@ -167,27 +167,27 @@ access to Lemonldap::NG Web-SSO sessions via SOAP.
   our @ISA = qw(Lemonldap::NG::Handler::Simple);
 
   __PACKAGE__->init ({
-  	     globalStorage => 'Lemonldap::NG::Manager::Apache::Session::SOAP',
-  	     globalStorageOptions => {
-  	             proxy => 'http://manager/cgi-bin/soapserver.pl',
-  	             proxyOptions => {
-  	                 timeout => 5,
-  	             },
-  	     },
+         globalStorage => 'Lemonldap::NG::Manager::Apache::Session::SOAP',
+         globalStorageOptions => {
+                 proxy => 'http://manager/cgi-bin/soapserver.pl',
+                 proxyOptions => {
+                     timeout => 5,
+                 },
+         },
          configStorage       => {
-  	         ... # See Lemonldap::NG::Handler
+             ... # See Lemonldap::NG::Handler
 
 =item * With Lemonldap::NG::Portal
 
   use Lemonldap::NG::Portal::SharedConf;
   my $portal = new Lemonldap::NG::Portal::SharedConf (
-  	     globalStorage => 'Lemonldap::NG::Manager::Apache::Session::SOAP',
-  	     globalStorageOptions => {
-  	             proxy => 'http://manager/cgi-bin/soapserver.pl',
-  	             proxyOptions => {
-  	                 timeout => 5,
-  	             },
-  	     },
+         globalStorage => 'Lemonldap::NG::Manager::Apache::Session::SOAP',
+         globalStorageOptions => {
+                 proxy => 'http://manager/cgi-bin/soapserver.pl',
+                 proxyOptions => {
+                     timeout => 5,
+                 },
+         },
         configStorage => {
              ... # See Lemonldap::NG::Portal
 
@@ -277,7 +277,8 @@ set environment variables.
 
 L<Lemonldap::NG::Manager::SOAPServer>,
 L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Manager::Conf::SOAP>,
-L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal>
+L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal>,
+http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
 
 =head1 AUTHOR
 
