@@ -8,8 +8,11 @@ use AutoLoader qw(AUTOLOAD);
 require Lemonldap::NG::Manager::_i18n;
 use Lemonldap::NG::Manager::Conf::Constants;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
+# TODO: Delete buttons in headers and rules if 'read-only'
+
+# TODO: Display errors in saveConf
 1;
 __END__
 
@@ -77,7 +80,8 @@ sub javascript {
                deleteNode locationRules unableToSave confSaved saveFailure
                newRule newHeader httpHeaders waitingResult unknownError
                configurationWasChanged configLoaded warningConfNotApplied
-               applyConf prevConf lastConf nextConf)) {
+               applyConf prevConf lastConf nextConf deleteVirtualHost
+               areYouSure syntaxError)) {
         $text{$_} = &{"txt_$_"};
         $text{$_} =~s/'/\\'/g;
     }
@@ -133,6 +137,15 @@ function onNodeSelect(nodeId) {
         k=tree.getItemText(nodeId);
         v='<textarea cols=40 rows=2 onChange="tree.setUserData('+"'"+nodeId+"'"+','+"'"+'value'+"'"+',this.value)">'+tree.getUserData(nodeId,'value')+'</textarea>';
         //v='<input size=80 name="value" value="'+tree.getUserData(nodeId,'value')+'" onChange="tree.setUserData('+"'"+nodeId+"'"+','+"'"+'value'+"'"+',this.value)">';
+        break;
+      case 'ro':
+        k=tree.getItemText(nodeId);
+        v='<p>'+tree.getUserData(nodeId,'value')+'</p>';
+        break;
+      case 'none':
+        k=tree.getItemText(nodeId);
+        v='<p>&nbsp;</p>';
+        break;
     }
     document.getElementById('formulaire').style.display='block';
     document.getElementById('name').innerHTML = k;
@@ -142,9 +155,10 @@ function onNodeSelect(nodeId) {
     document.getElementById('formulaire').style.display='none';
   }
   var but='';
-  if(nodeIs(nodeId,"virtualHosts")){
+  if(nodeIs(nodeId,"virtualHosts") && tree.getUserData(nodeId,"modif") != "none" && tree.getUserData(nodeId,"modif") != 'ro' ){
     but+=button('$text{newVirtualHost}','newVirtualHost',nodeId);
     if(nodeIs(nodeId,"virtualHost")){
+      but+=button('$text{deleteVirtualHost}','deleteVirtualHost',nodeId);
       but+=button('$text{newRule}','newRule',nodeId);
       but+=button('$text{newHeader}','newHeader',nodeId);
     }
@@ -184,9 +198,9 @@ function onNodeSelect(nodeId) {
   }
   if(tree.getUserData(nodeId,"modif")=='both') but+=button('$text{deleteNode}','deleteNode',nodeId);
   but+=button('$text{saveConf}','saveConf',nodeId);
-  if(nodeId == 'root') but+=button('$text{prevConf}','prevConf',nodeId)
+  /*if(nodeId == 'root') but+=button('$text{prevConf}','prevConf',nodeId)
                            +button('$text{nextConf}','nextConf',nodeId)
-                           +button('$text{lastConf}','lastConf',nodeId);
+                           +button('$text{lastConf}','lastConf',nodeId);*/
   #;
     if( $self->{applyConfFile} ) {
         print "but+=button('$text{applyConf}','applyConf',nodeId);";
@@ -234,6 +248,11 @@ function newVirtualHost() {
   }
 }
 
+function deleteVirtualHost(id) {
+  var vh=vhostId(id);
+  if(confirm('$text{areYouSure}')) tree.deleteItem(vh);
+}
+
 function newValue(id,text,type,value){
   indice--;
   insertNewChild(id,'j_'+indice,text);
@@ -304,11 +323,14 @@ function saveConf(){
         document.getElementById('help').innerHTML='<h3>$text{confSaved} : '+r+'</h3>$text{warningConfNotApplied}';
       }
       else if(r<0) {
-      	var txt='<h3>$text{saveFailure}: ';
-      	if(r==#.CONFIG_WAS_CHANGED.qq#) {
+        var txt='<h3>$text{saveFailure}: ';
+        if(r==#.CONFIG_WAS_CHANGED.qq#) {
           txt+='$text{configurationWasChanged}';
-      	}
-      	document.getElementById('help').innerHTML=txt+'</h3>';
+        }
+        else if(r==#.SYNTAX_ERROR.qq#) {
+          txt+='$text{syntaxError}';
+        }
+        document.getElementById('help').innerHTML=txt+'</h3>';
       }
       else document.getElementById('help').innerHTML='<h3>$text{unknownError}</h3>';
     }
@@ -342,6 +364,12 @@ function applyConf(){
   xhr_object.send(null);
 }
 
+function prevConf(){
+}
+
+function nextConf(){
+}
+
 function ec(s){
   if((!s) || s=='') return s;
   return s.replace(/>/g,'&gt;').replace(/</g,'&lt;');
